@@ -4,8 +4,7 @@
 #'
 #' @param surveyID String. Unique ID for the survey you want to download.
 #' Returned as \code{id} by the \link[qualtRics]{all_surveys} function.
-#' @param last_response String. Export all responses received after the
-#' specified response ID. Defaults to \code{NULL}.
+#' @param last_response Deprecated.
 #' @param start_date String. Filter to only exports responses recorded after the
 #' specified date. Accepts dates as character strings in format "YYYY-MM-DD".
 #' Defaults to \code{NULL}.
@@ -49,12 +48,18 @@
 #' \code{\link[qualtRics]{fetch_survey}} function will split multiple
 #' choice question answers into columns. If \code{FALSE}, each multiple choice
 #' question is one column. Defaults to \code{TRUE}.
+#' @param col_types Optional. This argument provides a way to manually overwrite
+#' column types that may be incorrectly guessed. Takes a \code{\link[readr]{cols}}
+#' specification. See example below and \code{\link[readr]{cols}} for formatting
+#' details. Defaults to \code{NULL}. Overwritten by \code{convert = TRUE}.
 #' @param ... Optional arguments, such as a `fileEncoding` (see `fileEncoding`
 #' argument in \code{\link[qualtRics]{read_survey}}) to import your survey using
 #' a specific encoding.
 #'
 #' @seealso See \url{https://api.qualtrics.com/reference} for documentation on
 #' the Qualtrics API.
+#'
+#' @importFrom lifecycle deprecated
 #' @export
 #' @examples
 #' \dontrun{
@@ -78,12 +83,14 @@
 #'   limit = 100,
 #'   label = TRUE,
 #'   unanswer_recode = 999,
-#'   verbose = TRUE
+#'   verbose = TRUE,
+#'   # Manually override EndDate to be a character vector
+#'   col_types = readr::cols(EndDate = readr::col_character())
 #' )
 #' }
 #'
 fetch_survey <- function(surveyID,
-                         last_response = NULL,
+                         last_response = deprecated(),
                          start_date = NULL,
                          end_date = NULL,
                          unanswer_recode = NULL,
@@ -99,8 +106,13 @@ fetch_survey <- function(surveyID,
                          import_id = FALSE,
                          time_zone = NULL,
                          breakout_sets = TRUE,
+                         col_types = NULL,
                          ...) {
 
+  if (lifecycle::is_present(last_response)) {
+    lifecycle::deprecate_warn("3.1.2", "fetch_survey(last_response = )")
+  }
+
   ## Are the API credentials stored?
   assert_base_url()
   assert_api_key()
@@ -111,7 +123,6 @@ fetch_survey <- function(surveyID,
     import_id = import_id,
     time_zone = time_zone,
     label = label,
-    last_response = last_response,
     start_date = start_date,
     end_date = end_date,
     include_questions = include_questions,
@@ -173,7 +184,8 @@ fetch_survey <- function(surveyID,
   # READ DATA AND SET VARIABLES ----
 
   # Read data
-  data <- read_survey(survey.fpath, import_id = import_id, time_zone = time_zone)
+  data <- read_survey(survey.fpath, import_id = import_id,
+                      time_zone = time_zone, col_types = col_types)
 
   # Add types
   if (convert & label) {
